# (C) 2014 Arulalan.T <arulalant@gmail.com>                                 
# This file is part of open-tamil/txt2uni  

from .encode2unicode import *
from .unicode2encode import *
